Imports System.Windows.Forms
Imports System.ComponentModel
Imports System.Resources
Imports CADImport
Imports CADImport.Printing
Imports CADImport.CADImportControls
Imports CADImport.FaceModule
Imports CADImport.CADImportForms

''' <summary>
''' Represents the main application form in which a <B>CADImportControl</B> is used for viewing CAD files.
''' </summary>
Public Class MainForm
    Inherits Form
    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="T:CADImportNetDemos.CADViewerControlDemo.MainForm">MainForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitializeComponent()
        Me.InitParams()
    End Sub

    <System.STAThread()> _
   Public Shared Sub Main()
        Application.EnableVisualStyles()
        Application.DoEvents()
        Application.Run(New MainForm)
    End Sub

    Private Sub ChangeControlState(ByVal val As Boolean)
        Me.miTextsShow.Checked = Me.cadViewerControl1.TextVisible
        Me.miDimShow.Checked = Me.cadViewerControl1.DimensionVisible
        Me.miShowLineWeight.Checked = Me.cadViewerControl1.ShowLineWeight
        Dim colorblack As Boolean = Me.cadViewerControl1.Image.BackgroundColor.Equals(Color.Black)
        Me.miBlackBackground.Checked = colorblack
        Me.miWhiteBackground.Checked = Not colorblack
        Me.miShowEntityTree.Checked = Me.cadViewerControl1.EntityTreeVisible
        Me.miDrawNormalColor.Checked = Me.cadViewerControl1.ColorDraw
        Me.miDrawBlackColor.Checked = Not Me.cadViewerControl1.ColorDraw
    End Sub

    Public Sub ChangeLanguage(ByVal val As String, ByVal index As Integer)
        Me.curLngIndex = index
        Me.lngFile = (val & ApplicationConstants.lngextstr)
        Me.SetAllFormsLanguageSettings()
        Me.SetLNG()
        Me.cadViewerControl1.ChangeControlState()
    End Sub

    Private Sub CreateNewSettingsList()
        Dim tmp As String
        MainForm.settingsLst = New SortedList
        MainForm.settingsLst.Add(ApplicationConstants.languagepath, Me.mlng.Path)
        MainForm.settingsLst.Add(ApplicationConstants.languagestr, Me.lngFile)
        MainForm.settingsLst.Add(ApplicationConstants.languageIDstr, Me.curLngIndex)
        If (Me.cadViewerControl1.ViewerCADPictureBox.BackColor.Equals(Color.Black)) Then
            tmp = ApplicationConstants.blackstr
        Else
            tmp = ApplicationConstants.whitestr
        End If
        MainForm.settingsLst.Add(ApplicationConstants.backcolorstr, tmp)
        MainForm.settingsLst.Add(ApplicationConstants.showentitystr, Me.cadViewerControl1.EntityTreeVisible)
        If (Not Me.cadViewerControl1.Image Is Nothing) Then
            MainForm.settingsLst.Add(ApplicationConstants.colorDraw, (Me.cadViewerControl1.Image.DrawMode = CADDrawMode.Normal))
        Else
            MainForm.settingsLst.Add(ApplicationConstants.colorDraw, Me.cadViewerControl1.ColorDraw)
        End If
        Dim cn As Integer = Me.cadViewerControl1.SHXForm.lstDir.Items.Count
        MainForm.settingsLst.Add(ApplicationConstants.shxpathcnstr, Me.cadViewerControl1.SHXForm.lstDir.Items.Count)
        Dim i As Integer
        For i = 0 To cn - 1
            MainForm.settingsLst.Add(("SHXPath_" & (i + 1)), Me.cadViewerControl1.SHXForm.lstDir.Items.Item(i))
        Next i
        Me.cadViewerControl1.NewProtectionSettings(MainForm.settingsLst)
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

    ''' <summary>
    ''' Enables or disables buttons of the toolbar and menu items of the main menu.
    ''' </summary>
    ''' <param name="aVal"><b>true</b> if to enable the buttons and menu items; <b>false</b> if to disable them.</param>
    ''' <remarks>The buttons and menu items are enabled after loading a CAD file and become disabled after closing the file.</remarks>
    Public Sub EnableButton(ByVal aVal As Boolean)
        Me.miScale.Enabled = aVal
        Me.miSaveFile.Enabled = aVal
        Me.miCopyAsBMP.Enabled = aVal
        Me.miZoomIn.Enabled = aVal
        Me.miZoomOut.Enabled = aVal
        Me.miFitToWindow.Enabled = aVal
        Me.miDrawNormalColor.Enabled = aVal
        Me.miDrawBlackColor.Enabled = aVal
        Me.miWhiteBackground.Enabled = aVal
        Me.miBlackBackground.Enabled = aVal
        Me.miChangeBackgroundColor.Enabled = aVal
        Me.miShowLineWeight.Enabled = aVal
        Me.miArcsSplit.Enabled = aVal
        Me.miDimShow.Enabled = aVal
        Me.miTextsShow.Enabled = aVal
        Me.miLayersShow.Enabled = aVal
        Me.mi3DViews.Enabled = aVal
        Me.miEnable3DOrbit.Enabled = aVal
        Me.miClosePicture.Enabled = aVal
        Me.miPrint.Enabled = aVal
        Me.miPrintPreview.Enabled = aVal
        Me.miCustomPrint.Enabled = aVal
        Me.miSaveAsDXF.Enabled = aVal
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Dim resources As New ResourceManager(GetType(MainForm))
        Me.saveDXFDlg = New SaveFileDialog
        Me.cadViewerControl1 = New CADViewerControl
        Me.mainMenu = New MainMenu
        Me.miFile = New MenuItem
        Me.miOpenFile = New MenuItem
        Me.miOpenFromWeb = New MenuItem
        Me.miSaveFile = New MenuItem
        Me.miSaveAsDXF = New MenuItem
        Me.miPrint = New MenuItem
        Me.miCustomPrint = New MenuItem
        Me.miPrintPreview = New MenuItem
        Me.miClosePicture = New MenuItem
        Me.miSeparator1 = New MenuItem
        Me.miExit = New MenuItem
        Me.editMenuItem = New MenuItem
        Me.miCopyAsBMP = New MenuItem
        Me.mView = New MenuItem
        Me.miShowEntityTree = New MenuItem
        Me.miSeparator2 = New MenuItem
        Me.miZoomIn = New MenuItem
        Me.miZoomOut = New MenuItem
        Me.miScale = New MenuItem
        Me.miZoom10 = New MenuItem
        Me.miZoom25 = New MenuItem
        Me.miZoom50 = New MenuItem
        Me.miZoom100 = New MenuItem
        Me.miZoom200 = New MenuItem
        Me.miZoom400 = New MenuItem
        Me.miZoom800 = New MenuItem
        Me.miFitToWindow = New MenuItem
        Me.miSeparator3 = New MenuItem
        Me.miShowShxForm = New MenuItem
        Me.miShowOptionsForm = New MenuItem
        Me.cADFilesMenuItem = New MenuItem
        Me.miDrawNormalColor = New MenuItem
        Me.miDrawBlackColor = New MenuItem
        Me.miWhiteBackground = New MenuItem
        Me.miBlackBackground = New MenuItem
        Me.miChangeBackgroundColor = New MenuItem
        Me.miSeparator4 = New MenuItem
        Me.miShowLineWeight = New MenuItem
        Me.miArcsSplit = New MenuItem
        Me.miDimShow = New MenuItem
        Me.miTextsShow = New MenuItem
        Me.miSeparator5 = New MenuItem
        Me.miLayersShow = New MenuItem
        Me.mi3DViews = New MenuItem
        Me.miInitialView = New MenuItem
        Me.miTopView = New MenuItem
        Me.miBottomView = New MenuItem
        Me.miLeftView = New MenuItem
        Me.miRightView = New MenuItem
        Me.miFrontView = New MenuItem
        Me.miBackView = New MenuItem
        Me.miSWIsometricView = New MenuItem
        Me.miSEIsometricView = New MenuItem
        Me.miNEIsometricView = New MenuItem
        Me.miNWIsometricView = New MenuItem
        Me.miEnable3DOrbit = New MenuItem
        Me.helpMenuItem = New MenuItem
        Me.miLanguages = New MenuItem
        Me.miRegistration = New MenuItem
        Me.miFloatLic = New MenuItem
        Me.miAbout = New MenuItem
        MyBase.SuspendLayout()
        Me.saveDXFDlg.DefaultExt = "*.dxf"
        Me.saveDXFDlg.Filter = "*.dxf|*.dxf"
        Me.cadViewerControl1.ColorDraw = True
        Me.cadViewerControl1.DimensionVisible = True
        Me.cadViewerControl1.Dock = DockStyle.Fill
        Me.cadViewerControl1.ColorDraw = True
        Me.cadViewerControl1.EntityPropertyGridVisible = True
        Me.cadViewerControl1.EntityTreeVisible = True
        Me.cadViewerControl1.Image = Nothing
        Me.cadViewerControl1.ImagePreviousScale = 1.0!
        Me.cadViewerControl1.ImageScale = 1.0!
        Me.cadViewerControl1.InFileName = ""
        Me.cadViewerControl1.LayoutsPanelVisible = True
        Me.cadViewerControl1.LeftImagePosition = 0.0!
        Me.cadViewerControl1.Location = New Point(0, 0)
        Me.cadViewerControl1.Name = "cadViewerControl1"
        Me.cadViewerControl1.OutFileName = ""
        Me.cadViewerControl1.Position = CType(resources.GetObject("cadViewerControl1.Position"), PointF)
        Me.cadViewerControl1.PreviousPosition = CType(resources.GetObject("cadViewerControl1.PreviousPosition"), PointF)
        Me.cadViewerControl1.PropertyEntityPanelVisible = True
        Me.cadViewerControl1.ShowLineWeight = False
        Me.cadViewerControl1.Size = New Size(720, &H193)
        Me.cadViewerControl1.StatusBarPanelVisible = True
        Me.cadViewerControl1.TabIndex = 0
        Me.cadViewerControl1.TextVisible = True
        Me.cadViewerControl1.ToolsPanelVisible = True
        Me.cadViewerControl1.TopImagePosition = 0.0!
        Me.cadViewerControl1.VisibleAreaSize = CType(resources.GetObject("cadViewerControl1.VisibleAreaSize"), SizeF)
        Me.mainMenu.MenuItems.AddRange(New MenuItem() {Me.miFile, Me.editMenuItem, Me.mView, Me.cADFilesMenuItem, Me.helpMenuItem})
        Me.miFile.Index = 0
        Me.miFile.MenuItems.AddRange(New MenuItem() {Me.miOpenFile, Me.miOpenFromWeb, Me.miSaveFile, Me.miSaveAsDXF, Me.miPrint, Me.miCustomPrint, Me.miPrintPreview, Me.miClosePicture, Me.miSeparator1, Me.miExit})
        Me.miFile.Text = "&File"
        Me.miOpenFile.Index = 0
        Me.miOpenFile.Shortcut = Shortcut.CtrlO
        Me.miOpenFile.Text = "Open Picture..."
        AddHandler Me.miOpenFile.Click, New System.EventHandler(AddressOf Me.miOpenFile_Click)
        Me.miOpenFromWeb.Index = 1
        Me.miOpenFromWeb.Text = "Open Picture from Web..."
        AddHandler Me.miOpenFromWeb.Click, New System.EventHandler(AddressOf Me.miOpenFromWeb_Click)
        Me.miSaveFile.Enabled = False
        Me.miSaveFile.Index = 2
        Me.miSaveFile.Text = "Save Picture..."
        AddHandler Me.miSaveFile.Click, New System.EventHandler(AddressOf Me.miSaveFile_Click)
        Me.miSaveAsDXF.Enabled = False
        Me.miSaveAsDXF.Index = 3
        Me.miSaveAsDXF.Text = "Save as DXF..."
        AddHandler Me.miSaveAsDXF.Click, New System.EventHandler(AddressOf Me.miSaveAsDXF_Click)
        Me.miPrint.Enabled = False
        Me.miPrint.Index = 4
        Me.miPrint.Text = "Print "
        AddHandler Me.miPrint.Click, New System.EventHandler(AddressOf Me.miPrint_Click)
        Me.miCustomPrint.Enabled = False
        Me.miCustomPrint.Index = 5
        Me.miCustomPrint.Shortcut = Shortcut.CtrlP
        Me.miCustomPrint.Text = "Custom Print Preview..."
        AddHandler Me.miCustomPrint.Click, New System.EventHandler(AddressOf Me.miCustomPrint_Click)
        Me.miPrintPreview.Enabled = False
        Me.miPrintPreview.Index = 6
        Me.miPrintPreview.Text = "Print Preview..."
        AddHandler Me.miPrintPreview.Click, New System.EventHandler(AddressOf Me.miPrintPreview_Click)
        Me.miClosePicture.Enabled = False
        Me.miClosePicture.Index = 7
        Me.miClosePicture.Text = "Close Picture"
        AddHandler Me.miClosePicture.Click, New System.EventHandler(AddressOf Me.miClosePicture_Click)
        Me.miSeparator1.Index = 8
        Me.miSeparator1.Text = "-"
        Me.miExit.Index = 9
        Me.miExit.Text = "Close"
        AddHandler Me.miExit.Click, New System.EventHandler(AddressOf Me.miExit_Click)
        Me.editMenuItem.Index = 1
        Me.editMenuItem.MenuItems.AddRange(New MenuItem() {Me.miCopyAsBMP})
        Me.editMenuItem.Text = "&Edit"
        Me.miCopyAsBMP.Enabled = False
        Me.miCopyAsBMP.Index = 0
        Me.miCopyAsBMP.Text = "Copy as BMP"
        AddHandler Me.miCopyAsBMP.Click, New System.EventHandler(AddressOf Me.miCopy_Click)
        Me.mView.Index = 2
        Me.mView.MenuItems.AddRange(New MenuItem() {Me.miShowEntityTree, Me.miSeparator2, Me.miZoomIn, Me.miZoomOut, Me.miScale, Me.miFitToWindow, Me.miSeparator3, Me.miShowShxForm, Me.miShowOptionsForm})
        Me.mView.Text = "&View"
        Me.miShowEntityTree.Checked = True
        Me.miShowEntityTree.Index = 0
        Me.miShowEntityTree.Text = "Show entities panel"
        AddHandler Me.miShowEntityTree.Click, New System.EventHandler(AddressOf Me.miEntities_Click)
        Me.miSeparator2.Index = 1
        Me.miSeparator2.Text = "-"
        Me.miZoomIn.Enabled = False
        Me.miZoomIn.Index = 2
        Me.miZoomIn.Text = "Zoom In (+)"
        AddHandler Me.miZoomIn.Click, New System.EventHandler(AddressOf Me.miZoomIn_Click)
        Me.miZoomOut.Enabled = False
        Me.miZoomOut.Index = 3
        Me.miZoomOut.Text = "Zoom Out (-)"
        AddHandler Me.miZoomOut.Click, New System.EventHandler(AddressOf Me.miZoomOut_Click)
        Me.miScale.Enabled = False
        Me.miScale.Index = 4
        Me.miScale.MenuItems.AddRange(New MenuItem() {Me.miZoom10, Me.miZoom25, Me.miZoom50, Me.miZoom100, Me.miZoom200, Me.miZoom400, Me.miZoom800})
        Me.miScale.Text = "Scale"
        Me.miZoom10.Index = 0
        Me.miZoom10.Text = "10%"
        AddHandler Me.miZoom10.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom25.Index = 1
        Me.miZoom25.Text = "25%"
        AddHandler Me.miZoom25.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom50.Index = 2
        Me.miZoom50.Text = "50%"
        AddHandler Me.miZoom50.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom100.Index = 3
        Me.miZoom100.Text = "100%"
        AddHandler Me.miZoom100.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom200.Index = 4
        Me.miZoom200.Text = "200%"
        AddHandler Me.miZoom200.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom400.Index = 5
        Me.miZoom400.Text = "400%"
        AddHandler Me.miZoom400.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miZoom800.Index = 6
        Me.miZoom800.Text = "800%"
        AddHandler Me.miZoom800.Click, New System.EventHandler(AddressOf Me.miScale_Click)
        Me.miFitToWindow.Enabled = False
        Me.miFitToWindow.Index = 5
        Me.miFitToWindow.Text = "Fit drawing to window"
        AddHandler Me.miFitToWindow.Click, New System.EventHandler(AddressOf Me.miFit_Click)
        Me.miSeparator3.Index = 6
        Me.miSeparator3.Text = "-"
        Me.miShowShxForm.Index = 7
        Me.miShowShxForm.Text = "SHX Fonts"
        AddHandler Me.miShowShxForm.Click, New System.EventHandler(AddressOf Me.miSHXFonts_Click)
        Me.miShowOptionsForm.Index = 8
        Me.miShowOptionsForm.Text = "Options"
        AddHandler Me.miShowOptionsForm.Click, New System.EventHandler(AddressOf Me.miOptions_Click)
        Me.cADFilesMenuItem.Index = 3
        Me.cADFilesMenuItem.MenuItems.AddRange(New MenuItem() {Me.miDrawNormalColor, Me.miDrawBlackColor, Me.miWhiteBackground, Me.miBlackBackground, Me.miChangeBackgroundColor, Me.miSeparator4, Me.miShowLineWeight, Me.miArcsSplit, Me.miDimShow, Me.miTextsShow, Me.miSeparator5, Me.miLayersShow, Me.mi3DViews, Me.miEnable3DOrbit})
        Me.cADFilesMenuItem.Text = "&CAD files"
        Me.miDrawNormalColor.Checked = True
        Me.miDrawNormalColor.Enabled = False
        Me.miDrawNormalColor.Index = 0
        Me.miDrawNormalColor.RadioCheck = True
        Me.miDrawNormalColor.Text = "Color drawing"
        AddHandler Me.miDrawNormalColor.Click, New System.EventHandler(AddressOf Me.miColor_Click)
        Me.miDrawBlackColor.Enabled = False
        Me.miDrawBlackColor.Index = 1
        Me.miDrawBlackColor.RadioCheck = True
        Me.miDrawBlackColor.Text = "Black drawing"
        AddHandler Me.miDrawBlackColor.Click, New System.EventHandler(AddressOf Me.miBlack_Click)
        Me.miWhiteBackground.Enabled = False
        Me.miWhiteBackground.Index = 2
        Me.miWhiteBackground.RadioCheck = True
        Me.miWhiteBackground.Text = "White Background"
        AddHandler Me.miWhiteBackground.Click, New System.EventHandler(AddressOf Me.miWhiteBack_Click)
        Me.miBlackBackground.Enabled = False
        Me.miBlackBackground.Index = 3
        Me.miBlackBackground.RadioCheck = True
        Me.miBlackBackground.Text = "Black Background"
        AddHandler Me.miBlackBackground.Click, New System.EventHandler(AddressOf Me.miBlackBack_Click)
        Me.miChangeBackgroundColor.Enabled = False
        Me.miChangeBackgroundColor.Index = 4
        Me.miChangeBackgroundColor.Text = "Change Background Color"
        AddHandler Me.miChangeBackgroundColor.Click, New System.EventHandler(AddressOf Me.miChangeBack_Click)
        Me.miSeparator4.Index = 5
        Me.miSeparator4.Text = "-"
        Me.miShowLineWeight.Enabled = False
        Me.miShowLineWeight.Index = 6
        Me.miShowLineWeight.Text = "Show Lineweight"
        AddHandler Me.miShowLineWeight.Click, New System.EventHandler(AddressOf Me.miShowLineWight_Click)
        Me.miArcsSplit.Checked = True
        Me.miArcsSplit.Enabled = False
        Me.miArcsSplit.Index = 7
        Me.miArcsSplit.Text = "Arcs Splitted"
        AddHandler Me.miArcsSplit.Click, New System.EventHandler(AddressOf Me.miArcsSplit_Click)
        Me.miDimShow.Checked = True
        Me.miDimShow.Enabled = False
        Me.miDimShow.Index = 8
        Me.miDimShow.Text = "Dimensions Show"
        AddHandler Me.miDimShow.Click, New System.EventHandler(AddressOf Me.miDimShow_Click)
        Me.miTextsShow.Checked = True
        Me.miTextsShow.Enabled = False
        Me.miTextsShow.Index = 9
        Me.miTextsShow.Text = "Texts Show"
        AddHandler Me.miTextsShow.Click, New System.EventHandler(AddressOf Me.miTextsShow_Click)
        Me.miSeparator5.Index = 10
        Me.miSeparator5.Text = "-"
        Me.miLayersShow.Enabled = False
        Me.miLayersShow.Index = 11
        Me.miLayersShow.Text = "Show Layers"
        AddHandler Me.miLayersShow.Click, New System.EventHandler(AddressOf Me.miLayersShow_Click)
        Me.mi3DViews.Enabled = False
        Me.mi3DViews.Index = 12
        Me.mi3DViews.MenuItems.AddRange(New MenuItem() {Me.miInitialView, Me.miTopView, Me.miBottomView, Me.miLeftView, Me.miRightView, Me.miFrontView, Me.miBackView, Me.miSWIsometricView, Me.miSEIsometricView, Me.miNEIsometricView, Me.miNWIsometricView})
        Me.mi3DViews.Text = "3D &Views"
        Me.miInitialView.Index = 0
        Me.miInitialView.Text = "Initial View"
        AddHandler Me.miInitialView.Click, New System.EventHandler(AddressOf Me.miInitialView_Click)
        Me.miTopView.Index = 1
        Me.miTopView.Text = "Top View"
        AddHandler Me.miTopView.Click, New System.EventHandler(AddressOf Me.miTopView_Click)
        Me.miBottomView.Index = 2
        Me.miBottomView.Text = "Bottom View"
        AddHandler Me.miBottomView.Click, New System.EventHandler(AddressOf Me.miBottomView_Click)
        Me.miLeftView.Index = 3
        Me.miLeftView.Text = "Left View"
        AddHandler Me.miLeftView.Click, New System.EventHandler(AddressOf Me.miLeftView_Click)
        Me.miRightView.Index = 4
        Me.miRightView.Text = "Right View"
        AddHandler Me.miRightView.Click, New System.EventHandler(AddressOf Me.miRightView_Click)
        Me.miFrontView.Index = 5
        Me.miFrontView.Text = "Front View"
        AddHandler Me.miFrontView.Click, New System.EventHandler(AddressOf Me.miFrontView_Click)
        Me.miBackView.Index = 6
        Me.miBackView.Text = "Back View"
        AddHandler Me.miBackView.Click, New System.EventHandler(AddressOf Me.miBackView_Click)
        Me.miSWIsometricView.Index = 7
        Me.miSWIsometricView.Text = "SW Isometric"
        AddHandler Me.miSWIsometricView.Click, New System.EventHandler(AddressOf Me.miSWIsometricView_Click)
        Me.miSEIsometricView.Index = 8
        Me.miSEIsometricView.Text = "SE Isometic"
        AddHandler Me.miSEIsometricView.Click, New System.EventHandler(AddressOf Me.miSEIsometricView_Click)
        Me.miNEIsometricView.Index = 9
        Me.miNEIsometricView.Text = "NE Isometric"
        AddHandler Me.miNEIsometricView.Click, New System.EventHandler(AddressOf Me.miNEIsometricView_Click)
        Me.miNWIsometricView.Index = 10
        Me.miNWIsometricView.Text = "NW Isometric"
        AddHandler Me.miNWIsometricView.Click, New System.EventHandler(AddressOf Me.miNWIsometricView_Click)
        Me.miEnable3DOrbit.Enabled = False
        Me.miEnable3DOrbit.Index = 13
        Me.miEnable3DOrbit.Text = "3D Orbit"
        AddHandler Me.miEnable3DOrbit.Click, New System.EventHandler(AddressOf Me.miEnable3DOrbit_Click)
        Me.helpMenuItem.Index = 4
        Me.helpMenuItem.MenuItems.AddRange(New MenuItem() {Me.miLanguages, Me.miRegistration, Me.miFloatLic, Me.miAbout})
        Me.helpMenuItem.Text = "&?"
        Me.miLanguages.Index = 0
        Me.miLanguages.Text = "Language"
        Me.miRegistration.Index = 1
        Me.miRegistration.Text = "Register "
        AddHandler Me.miRegistration.Click, New System.EventHandler(AddressOf Me.miRegister_Click)
        Me.miFloatLic.Index = 2
        Me.miFloatLic.Text = "Floating License Registration..."
        AddHandler Me.miFloatLic.Click, New System.EventHandler(AddressOf Me.miFloatLic_Click)
        Me.miAbout.Index = 3
        Me.miAbout.Text = "About..."
        AddHandler Me.miAbout.Click, New System.EventHandler(AddressOf Me.miAbout_Click)
        Me.AutoScaleBaseSize = New Size(5, 13)
        MyBase.ClientSize = New Size(720, &H193)
        MyBase.Controls.Add(Me.cadViewerControl1)
        MyBase.Menu = Me.mainMenu
        MyBase.Name = "MainForm"
        MyBase.StartPosition = FormStartPosition.CenterScreen
        Me.Text = "Viewer"
        MyBase.WindowState = FormWindowState.Maximized
        AddHandler MyBase.Closing, New CancelEventHandler(AddressOf Me.MainForm_Closing)
        AddHandler MyBase.Load, New System.EventHandler(AddressOf Me.MainForm_Load)
        AddHandler MyBase.Closed, New System.EventHandler(AddressOf Me.MainForm_Closed)
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Private Sub InitLng()
        Me.mlng = New MultipleLanguage(MyBase.GetType)
        If (Not Me.mainMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.mainMenu.MenuItems)
        End If
        If (Not Me.ContextMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.ContextMenu.MenuItems)
        End If
        Me.mlng.SaveNameNoNameElement(MyBase.Controls)
    End Sub

    Private Sub InitParams()
        Me.svSet = New SaveSettings(MainForm.fileSettingsName)
        MainForm.settingsLst = Me.svSet.LoadOptions
        Me.lngFile = ApplicationConstants.defaultstr
        Me.curLngIndex = 0
        Me.InitLng()
        If (MainForm.settingsLst Is Nothing) Then
            Me.CreateNewSettingsList()
        Else
            Me.SetSettings()
        End If
        Me.ReloadLNG()
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngIndex) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = True
        End If
        Me.SetAllFormsSettings()
        AddHandler Me.cadViewerControl1.ChangeTextShow, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.ChangeDimensionShow, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.ChangeLineWeightShow, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.ChangeBackgroundColor, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.OptionsForm.ChangeBackgroundColor, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.OptionsForm.ChangeDrawingColors, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        AddHandler Me.cadViewerControl1.OptionsForm.ChangeEntityPanelVisible, New ChangeOptionsEventHandler(AddressOf Me.ChangeControlState)
        Me.cadViewerControl1.OptionsForm.SettingsList = MainForm.settingsLst
    End Sub

    Private Sub InitSettings()
        Me.svSet = New SaveSettings(MainForm.fileSettingsName)
        MainForm.settingsLst = Me.svSet.LoadOptions
        If (Not MainForm.settingsLst Is Nothing) Then
            Dim key As String = ApplicationConstants.languagepath
            If MainForm.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(MainForm.settingsLst.Item(key))
            End If
        Else
            Me.mlng.Path = ".\Languages"
        End If
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (MainForm.settingsLst Is Nothing) Then
            Me.CreateNewSettingsList()
        Else
            Me.SetSettings()
        End If
    End Sub

    Private Sub LanguageSelect_Click(ByVal sender As Object, ByVal e As EventArgs)
        If TypeOf sender Is MenuItem Then
            Dim mn As MenuItem = CType(sender, MenuItem)
            Me.curLngIndex = CByte(mn.Index)
            Me.lngFile = (mn.Text & ApplicationConstants.lngextstr)
            Me.SetAllFormsLanguageSettings()
            Me.SetLNG()
            Me.cadViewerControl1.ChangeControlState()
        End If
    End Sub

    Private Sub MainForm_Closed(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.Unregister()
    End Sub

    Private Sub MainForm_Closing(ByVal sender As Object, ByVal e As CancelEventArgs)
        Me.CreateNewSettingsList()
        Me.svSet.SaveOptions(MainForm.settingsLst)
    End Sub

    Private Sub MainForm_Load(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.Register()
        Me.EnableButton(True)
    End Sub

    Private Sub menuItemAbout_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.AboutForm.ShowDialog()
    End Sub

    Private Sub miAbout_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.AboutForm.ShowDialog()
    End Sub

    Private Sub miArcsSplit_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.miArcsSplit.Checked = Not Me.miArcsSplit.Checked
        Me.cadViewerControl1.UseWinEllipse()
        Me.cadViewerControl1.ChangeControlState()
    End Sub

    Private Sub miBackView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetBackView()
    End Sub

    Private Sub miBlack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.miDrawNormalColor.Checked = False
        Me.miDrawBlackColor.Checked = True
        Me.cadViewerControl1.DoBlackColor()
        Me.cadViewerControl1.ChangeControlState()
    End Sub

    Private Sub miBlackBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.Black_Click()
    End Sub

    Private Sub miBottomView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetBottomView()
    End Sub

    Private Sub miChangeBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.Color_Click()
        Me.cadViewerControl1.ChangeControlState()
    End Sub

    Private Sub miClosePicture_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.CloseFile()
    End Sub

    Private Sub miColor_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.miDrawNormalColor.Checked = True
        Me.miDrawBlackColor.Checked = False
        Me.cadViewerControl1.DoNormalColor()
        Me.cadViewerControl1.ChangeControlState()
    End Sub

    Private Sub miCopy_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadViewerControl1.Image Is Nothing) Then
            Dim tmpRect As New DRect(0, 0, CDbl((Me.cadViewerControl1.ClientRectangle.Width * Me.cadViewerControl1.ImageScale)), CDbl((Me.cadViewerControl1.ClientRectangle.Height * Me.cadViewerControl1.ImageScale)))
            Me.cadViewerControl1.Image.SaveImageToClipboard(tmpRect)
        End If
    End Sub

    Private Sub miCustomPrint_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.PrintingForm.ShowDialog()
    End Sub

    Private Sub miDimShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ChangeDimensionsVisiblity(Not Me.cadViewerControl1.Image.DimensionsVisible)
    End Sub

    Private Sub miEnable3DOrbit_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.Enable3DOrbit()
    End Sub

    Private Sub miEntities_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.PropertyEntityPanelVisible = Not Me.cadViewerControl1.PropertyEntityPanelVisible
        Me.miShowEntityTree.Checked = Me.cadViewerControl1.EntityTreeVisible
        Me.cadViewerControl1.DoResize()
    End Sub

    Private Sub miExit_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.Close()
    End Sub

    Private Sub miFit_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ResetScaling()
    End Sub

    Private Sub miFloatLic_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.FloatingRegistrationForm.ShowDialog()
    End Sub

    Private Sub miFrontView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetFrontView()
    End Sub

    Private Sub miInitialView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetInitialView()
    End Sub

    Private Sub miLayersShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadViewerControl1.Image Is Nothing) Then
            Me.cadViewerControl1.LayerForm.ShowDialog()
        End If
    End Sub

    Private Sub miLeftView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetLeftView()
    End Sub

    Private Sub miNEIsometricView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetNEIsometricView()
    End Sub

    Private Sub miNWIsometricView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetNWIsometricView()
    End Sub

    Private Sub miOpenFile_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ShowLoadFileDialog()
    End Sub

    Private Sub miOpenFromWeb_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ShowOpenFromWebForm()
    End Sub

    Private Sub miOptions_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.CreateNewSettingsList()
        Me.cadViewerControl1.OptionsForm.SettingsList = MainForm.settingsLst
        Me.cadViewerControl1.OptionsForm.ShowDialog()
    End Sub

    Private Sub miPrint_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadViewerControl1.Image Is Nothing) Then
            Me.cadViewerControl1.Image.Print(True, True)
        End If
    End Sub

    Private Sub miPrintPreview_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.PrintingForm.TypePage = DrawingSize.Fit
        Me.cadViewerControl1.PrintPreviewDialog.Document = Me.cadViewerControl1.PrintingForm.Print(False)
        Me.cadViewerControl1.PrintPreviewDialog.ShowDialog()
        If (Not Me.cadViewerControl1.PrintPreviewDialog.Document Is Nothing) Then
            Me.cadViewerControl1.PrintPreviewDialog.Document.Dispose()
        End If
    End Sub

    Private Sub miRegister_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.RegistrationForm.ShowDialog()
    End Sub

    Private Sub miRightView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetRightView()
    End Sub

    Private Sub miSaveAsDXF_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SaveAsDXF()
    End Sub

    Private Sub miSaveDXF_Click(ByVal sender As Object, ByVal e As EventArgs)
        If ((Not Me.cadViewerControl1.Image Is Nothing) AndAlso (Me.saveDXFDlg.ShowDialog = DialogResult.OK)) Then
            Me.cadViewerControl1.SaveAsDXF(Me.saveDXFDlg.FileName)
        End If
    End Sub

    Private Sub miSaveFile_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SaveAsImage()
    End Sub

    Private Sub miScale_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadViewerControl1.Image Is Nothing) Then
            Dim i As Single = Me.cadViewerControl1.ImageScale
            Select Case CType(sender, MenuItem).Index
                Case 0
                    i = 0.1!
                    Exit Select
                Case 1
                    i = 0.25!
                    Exit Select
                Case 2
                    i = 0.5!
                    Exit Select
                Case 3
                    i = 1.0!
                    Exit Select
                Case 4
                    i = 2.0!
                    Exit Select
                Case 5
                    i = 4.0!
                    Exit Select
                Case 6
                    i = 8.0!
                    Exit Select
            End Select
            Me.cadViewerControl1.ResetScaling()
            Me.cadViewerControl1.ImageScale = i
            Me.cadViewerControl1.InvalidateImage()
        End If
    End Sub

    Private Sub miSEIsometricView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetSEIsometricView()
    End Sub

    Private Sub miShowLineWight_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ChangeShowLineWeight(Not Me.cadViewerControl1.ShowLineWeight)
    End Sub

    Private Sub miSHXFonts_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.AddSHXPaths()
    End Sub

    Private Sub miSWIsometricView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetSWIsometricView()
    End Sub

    Private Sub miTextsShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.ChangeTextsVisiblity(Not Me.cadViewerControl1.TextVisible)
    End Sub

    Private Sub miTopView_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.SetTopView()
    End Sub

    Private Sub miWhiteBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.White_Click()
    End Sub

    Private Sub miZoomIn_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.DoZoomIn()
    End Sub

    Private Sub miZoomOut_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadViewerControl1.DoZoomOut()
    End Sub

    Friend Sub ReloadLNG()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
    End Sub

    Friend Sub ReloadLNG(ByVal val As String)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.Path = val
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngIndex) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = True
        End If
    End Sub

    Private Sub SelectLanguage()
        Dim i As Integer
        For i = 0 To Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count - 1
            If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(i).Text = "English") Then
                Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(i).Checked = True
                Me.curLngIndex = i
                Exit For
            End If
        Next i
    End Sub

    Private Sub SetAllFormsLanguageSettings()
        Me.cadViewerControl1.OptionsForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.OptionsForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.AboutForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.AboutForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.FloatingRegistrationForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.FloatingRegistrationForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.LayerForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.LayerForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.PrintingForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.PrintingForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.RegistrationForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.RegistrationForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.RasterSizeForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.RasterSizeForm.LngFileName = Me.lngFile
        Me.cadViewerControl1.SHXForm.MultipleLanguagesPath = Me.mlng.Path
        Me.cadViewerControl1.SHXForm.LngFileName = Me.lngFile
    End Sub

    Private Sub SetAllFormsSettings()
        Me.SetAllFormsLanguageSettings()
        Me.cadViewerControl1.OptionsForm.SettingsList = MainForm.settingsLst
        AddHandler Me.cadViewerControl1.OptionsForm.ChangeLngPath, New ChangeLngPathEventHandler(AddressOf Me.ReloadLNG)
        AddHandler Me.cadViewerControl1.OptionsForm.ChangeLanguage, New ChangeLanguageEventHandler(AddressOf Me.ChangeLanguage)
    End Sub

    Private Sub SetLNG()
        Me.mlng.LoadLNG(Me.lngFile)
        Me.mlng.RestoreLanguage(MyBase.Controls, MyBase.Menu)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        Me.Text = ApplicationConstants.appnamestr
        Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngIndex) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = True
        End If
    End Sub

    Friend Sub SetSettings()
        If (Not MainForm.settingsLst Is Nothing) Then
            Dim cn As Integer = 0
            Dim key As String = ApplicationConstants.languagepath
            If MainForm.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(MainForm.settingsLst.Item(key))
            End If
            key = ApplicationConstants.languagestr
            If MainForm.settingsLst.ContainsKey(key) Then
                Me.lngFile = CStr(MainForm.settingsLst.Item(key))
            End If
            Me.mlng.LoadLNG(Me.lngFile)
            Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
            key = ApplicationConstants.languageIDstr
            If MainForm.settingsLst.ContainsKey(key) Then
                Me.curLngIndex = Convert.ToByte(MainForm.settingsLst.Item(key))
            End If
            key = ApplicationConstants.backcolorstr
            Dim tmp As String = ApplicationConstants.blackstr
            If MainForm.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(MainForm.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.blackstr) Then
                Me.cadViewerControl1.Black_Click()
            Else
                Me.cadViewerControl1.White_Click()
            End If
            key = ApplicationConstants.showentitystr
            If MainForm.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(MainForm.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.cadViewerControl1.EntityTreeVisible = True
            Else
                Me.cadViewerControl1.EntityTreeVisible = False
            End If
            key = ApplicationConstants.drawmodestr
            If MainForm.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(MainForm.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.cadViewerControl1.ColorDraw = True
            Else
                Me.cadViewerControl1.ColorDraw = False
            End If
            key = ApplicationConstants.shxpathcnstr
            If MainForm.settingsLst.ContainsKey(key) Then
                cn = Convert.ToInt32(MainForm.settingsLst.Item(key))
            End If
            Dim i As Integer
            For i = 0 To cn - 1
                key = String.Format("SHXPath_{0}", (i + 1))
                If MainForm.settingsLst.ContainsKey(key) Then
                    Me.cadViewerControl1.SHXForm.AddPath(Convert.ToString(MainForm.settingsLst.Item(key)))
                End If
            Next i
            key = ApplicationConstants.installstr
            If (MainForm.settingsLst.ContainsKey(key) AndAlso CADConst.SearchSHXPaths) Then
                Me.cadViewerControl1.SHXForm.lstDir.Items.Clear()
                Me.cadViewerControl1.SHXForm.lstPath.Clear()
                Dim vPaths As New ArrayList
                CADConst.FindAutoCADSHXPaths(vPaths)
                For i = 0 To vPaths.Count - 1
                    tmp = CStr(vPaths.Item(i))
                    Me.cadViewerControl1.SHXForm.lstDir.Items.Add(tmp)
                    Me.cadViewerControl1.SHXForm.lstPath.Add(tmp, String.Empty)
                    CADConst.SHXSearchPaths = (CADConst.SHXSearchPaths & CADConst.SHXSearchPaths & tmp & ApplicationConstants.sepstr3)
                Next i
            End If
            key = ApplicationConstants.typelcstr
            If MainForm.settingsLst.ContainsKey(key) Then
                tmp = CStr(MainForm.settingsLst.Item(key))
                If (tmp = ApplicationConstants.floatingstr) Then
                    Protection.LicenseType = LicenseType.Floating
                    key = ApplicationConstants.hoststr
                    If MainForm.settingsLst.ContainsKey(key) Then
                        Me.cadViewerControl1.FloatingRegistrationForm.Host = CStr(MainForm.settingsLst.Item(key))
                    End If
                    key = ApplicationConstants.portstr
                    If MainForm.settingsLst.ContainsKey(key) Then
                        Me.cadViewerControl1.FloatingRegistrationForm.Port = Convert.ToInt32(MainForm.settingsLst.Item(key))
                    End If
                    key = ApplicationConstants.appconst
                    If MainForm.settingsLst.ContainsKey(key) Then
                        Me.cadViewerControl1.FloatingRegistrationForm.App = CStr(MainForm.settingsLst.Item(key))
                    End If
                Else
                    Protection.LicenseType = LicenseType.Register
                End If
            End If
        End If
    End Sub


    ' Fields
    Private cADFilesMenuItem As MenuItem
    Private cadViewerControl1 As CADViewerControl
    Private components As Container = Nothing
    Private curLngIndex As Integer
    Private editMenuItem As MenuItem
    Private Shared ReadOnly fileSettingsName As String = (Application.StartupPath & "\Settings.txt")
    Private helpMenuItem As MenuItem
    Private lngFile As String
    Private mainMenu As mainMenu
    Private mi3DViews As MenuItem
    Private miAbout As MenuItem
    Private miArcsSplit As MenuItem
    Private miBackView As MenuItem
    Private miBlackBackground As MenuItem
    Private miBottomView As MenuItem
    Private miChangeBackgroundColor As MenuItem
    Private miClosePicture As MenuItem
    Private miCopyAsBMP As MenuItem
    Private miCustomPrint As MenuItem
    Private miDimShow As MenuItem
    Private miDrawBlackColor As MenuItem
    Private miDrawNormalColor As MenuItem
    Private miEnable3DOrbit As MenuItem
    Private miExit As MenuItem
    Private miFile As MenuItem
    Private miFitToWindow As MenuItem
    Private miFloatLic As MenuItem
    Private miFrontView As MenuItem
    Private miInitialView As MenuItem
    Private miLanguages As MenuItem
    Private miLayersShow As MenuItem
    Private miLeftView As MenuItem
    Private miNEIsometricView As MenuItem
    Private miNWIsometricView As MenuItem
    Private miOpenFile As MenuItem
    Private miOpenFromWeb As MenuItem
    Private miPrint As MenuItem
    Private miPrintPreview As MenuItem
    Private miRegistration As MenuItem
    Private miRightView As MenuItem
    Private miSaveAsDXF As MenuItem
    Private miSaveFile As MenuItem
    Private miScale As MenuItem
    Private miSEIsometricView As MenuItem
    Private miSeparator1 As MenuItem
    Private miSeparator2 As MenuItem
    Private miSeparator3 As MenuItem
    Private miSeparator4 As MenuItem
    Private miSeparator5 As MenuItem
    Private miShowEntityTree As MenuItem
    Private miShowLineWeight As MenuItem
    Private miShowOptionsForm As MenuItem
    Private miShowShxForm As MenuItem
    Private miSWIsometricView As MenuItem
    Private miTextsShow As MenuItem
    Private miTopView As MenuItem
    Private miWhiteBackground As MenuItem
    Private miZoom10 As MenuItem
    Private miZoom100 As MenuItem
    Private miZoom200 As MenuItem
    Private miZoom25 As MenuItem
    Private miZoom400 As MenuItem
    Private miZoom50 As MenuItem
    Private miZoom800 As MenuItem
    Private miZoomIn As MenuItem
    Private miZoomOut As MenuItem
    Private mlng As MultipleLanguage
    Private mView As MenuItem
    Private saveDXFDlg As SaveFileDialog
    Private Shared settingsLst As SortedList
    Private svSet As SaveSettings
End Class

Friend MustInherit Class ApplicationConstants
    ' Methods
    Protected Sub New()
    End Sub

    ' Fields
    Public Shared ReadOnly appconst As String = "Application"
    Public Shared ReadOnly appnamestr As String = "CADImportNet Demo"
    Public Shared ReadOnly backcolorstr As String = "BackgroundColor"
    Public Shared ReadOnly blackstr As String = "BLACK"
    Public Shared ReadOnly blackstr2 As String = "Black"
    Public Shared ReadOnly colorDraw As String = "ColorDraw"
    Public Shared ReadOnly colorstr As String = "Color"
    Public Shared ReadOnly defaultstr As String = "Default"
    Public Shared ReadOnly drawmodestr As String = "drawMode"
    Public Shared ReadOnly floatingstr As String = "floating"
    Public Shared ReadOnly freezestr As String = "Freeze"
    Public Shared ReadOnly hoststr As String = "Host"
    Public Shared ReadOnly installstr As String = "Install"
    Public Shared ReadOnly languageIDstr As String = "LanguageID"
    Public Shared ReadOnly languagepath As String = "LanguagePath"
    Public Shared ReadOnly languagestr As String = "Language"
    Public Shared ReadOnly lngextstr As String = ".lng"
    Public Shared ReadOnly msgBoxDebugCaption As String = "Debug application message"
    Public Shared ReadOnly namestr As String = "Name"
    Public Shared ReadOnly notsupportedextstr As String = "Not supported in current version!"
    Public Shared ReadOnly notsupportedstr As String = "not supported"
    Public Shared ReadOnly portstr As String = "Port"
    Public Shared ReadOnly registerstr As String = "register"
    Public Shared ReadOnly sepstr As String = " - "
    Public Shared ReadOnly sepstr2 As String = " : "
    Public Shared ReadOnly sepstr3 As String = ";"
    Public Shared ReadOnly showentitystr As String = "ShowEntity"
    Public Shared ReadOnly shxpathcnstr As String = "SHXPathCount"
    Public Shared ReadOnly truestr As String = "TRUE"
    Public Shared ReadOnly typelcstr As String = "Type_license"
    Public Shared ReadOnly visiblestr As String = "Visible"
    Public Shared ReadOnly whitestr As String = "White"
End Class


